enum ClauseNode {
Root,
Clause(ItemId, TraitClauseId),
}Variants
Root
A special node to indicate clauses that we consider unconditionally used. Unused clauses will in the end be the ones unreachable from the root.
Clause(ItemId, TraitClauseId)
The nth clause parameter of that item.